@@ -1,4 +1,4 @@
-use bitaccess::bitaccess;
+use bitaccess::{bitaccess, ReadBits, WriteBits};
 
 #[bitaccess(base_type = u64, kind = default)]
 #[derive(Clone, Debug, PartialEq)]
@@ -77,8 +77,32 @@ fn propagates_top_level_attributes() {
 
 #[test]
 fn can_use_custom_read_via() {
+    unsafe { GLOBAL_TEST = 0 };
     let mut r = ViaTests::new();
     r.write(ViaTests::BitZero, 0b1u64);
     assert_eq!(r.read(ViaTests::BitZero).value(), 1);
     assert_eq!(unsafe { GLOBAL_TEST }, 1);
 }
+
+#[test]
+fn can_call_directly() {
+    unsafe { GLOBAL_TEST = 0 };
+    ViaTests.write(ViaTests::BitZero, 1);
+    assert_eq!(ViaTests.read(ViaTests::BitZero).value(), 1)
+}
+
+#[test]
+fn can_zero_fields() {
+    let mut r = Register::from_value(0b1111_0000);
+    r.write(Register::F2, 0);
+    assert_eq!(r.read(Register::F2).value(), 0);
+}
+
+#[test]
+fn set_overwrites_value() {
+    let mut r = Register::from_value(0b1111_0000);
+    r.set(0);
+    r.set(1);
+    r.set(0b10);
+    assert_eq!(r.get(), 0b10);
+}
