@@ -1,4 +1,4 @@
-use bitaccess::{bitaccess, FieldAccess};
+use bitaccess::{bitaccess, FieldAccess, ReadBits, WriteBits};
 
 #[bitaccess(base_type = u64)]
 pub enum Variants {
@@ -26,6 +26,14 @@ pub enum ExternalVariants {
     FourBits,
 }
 
+static mut FIELD: u32 = 0;
+
+#[bitaccess(base_type = u32, kind = write_only, write_via = "unsafe { crate::FIELD = value }")]
+pub enum WriteOnly {
+    #[bits(0..16)]
+    Field,
+}
+
 #[test]
 fn can_use_variants() {
     let mut r = Variants::new();
@@ -42,3 +50,11 @@ fn can_use_external_variants() {
         FourBitsVariant::Case3,
     )
 }
+
+#[test]
+fn can_be_write_only() {
+    let mut r = WriteOnly::new();
+    r.write(WriteOnly::Field, 1);
+
+    assert_eq!(unsafe { FIELD }, 1);
+}
